==> ejc-settle-impl-3.0.0-20240618.002543-48-sources.jar: com/ejianc/business/settle/vo/SettlementCenterUserProjectMainVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算中心人员主信息
 * 
 * @author generator
 * 
 */
public class SettlementCenterUserProjectMainVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long userId; // 人员id
    private String userName; // 用户名称
    private String userCode; // 用户账号
    private Long orgId; // 结算中心组织ID
    private Integer major; // 结算中心专业 0土建、1机务、2电仪 使用方式1
    private String roles; // 结算中心角色 节点1,节点2,节点3,节点4,节点5,节点6,节点7 使用方式1,2
    

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }
    public String getRoles() {
        return roles;
    }

    public void setRoles(String roles) {
        this.roles = roles;
    }
    
}

==> ejc-settle-impl-3.0.0-20240708.072402-71-sources.jar: com/ejianc/business/settle/vo/SettlementCenterUserProjectMainVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算中心人员主信息
 * 
 * @author generator
 * 
 */
public class SettlementCenterUserProjectMainVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long userId; // 人员id
    private String userName; // 用户名称
    private String userCode; // 用户账号
    private Long orgId; // 结算中心组织ID
    private Integer major; // 结算中心专业 0土建、1机务、2电仪 使用方式1
    private String roles; // 结算中心角色 节点1,节点2,节点3,节点4,节点5,节点6,节点7 使用方式1,2
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Integer getMajor() {
        return major;
    }

    public void setMajor(Integer major) {
        this.major = major;
    }
    public String getRoles() {
        return roles;
    }

    public void setRoles(String roles) {
        this.roles = roles;
    }
    
}
